<p align="center">
<a href='https://datasystemsgrouput.github.io/PAPyA/'><img src="https://github.com/DataSystemsGroupUT/PAPyA/blob/main/figs/papayalogo.png" width="100"/> </a>
</p>

# <a href='https://datasystemsgrouput.github.io/PAPyA/'>PAPyA</a>

Prescriptive Performance Analysis  in Python Actions 

[![DOI](https://zenodo.org/badge/487547762.svg)](https://zenodo.org/badge/latestdoi/487547762)

This library provides prescriptive analysis for the complex solution space of (RDF relational schema, Partitioning, and Storage Formats) that emerges with querying large RDF graphs over Relational Big Data (BD) System, e.g., Apache Spark-SQL.

* Documentation and more details about <a href='https://datasystemsgrouput.github.io/PAPyA/'> PAPya </a>
